@@ -37,8 +37,6 @@
 
 #include "gcm-x11-screen.h"
 
-#include "egg-debug.h"
-
 static void     gcm_x11_screen_finalize	(GObject     *object);
 
 #define GCM_X11_SCREEN_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GCM_TYPE_X11_SCREEN, GcmX11ScreenPrivate))
@@ -87,7 +85,7 @@ gcm_x11_screen_on_event_cb (GdkXEvent *xevent, GdkEvent *event, gpointer data)
 	event_num = e->type - priv->randr_event_base;
 
 	if (event_num == RRScreenChangeNotify) {
-		egg_debug ("emit changed");
+		g_debug ("emit changed");
 		g_signal_emit (screen, signals[SIGNAL_CHANGED], 0);
 	}
 
@@ -135,7 +133,7 @@ gcm_x11_screen_refresh (GcmX11Screen *screen, GError **error)
 		output_info = XRRGetOutputInfo (priv->xdisplay, resources, rr_output);
 		gdk_flush ();
 		if (gdk_error_trap_pop ()) {
-			egg_warning ("failed to get output info");
+			g_warning ("failed to get output info");
 			continue;
 		}
 
@@ -147,7 +145,7 @@ gcm_x11_screen_refresh (GcmX11Screen *screen, GError **error)
 			crtc_info = XRRGetCrtcInfo (priv->xdisplay, resources, output_info->crtc);
 			gdk_flush ();
 			if (gdk_error_trap_pop () || crtc_info == NULL) {
-				egg_warning ("failed to get crtc info for %s", output_info->name);
+				g_warning ("failed to get crtc info for %s", output_info->name);
 				continue;
 			}
 
@@ -156,7 +154,7 @@ gcm_x11_screen_refresh (GcmX11Screen *screen, GError **error)
 			gamma_size = XRRGetCrtcGammaSize (priv->xdisplay, output_info->crtc);
 			gdk_flush ();
 			if (gdk_error_trap_pop ()) {
-				egg_warning ("failed to get gamma size");
+				g_warning ("failed to get gamma size");
 				continue;
 			}
 
@@ -197,7 +195,7 @@ out:
  *
  * Return value: %TRUE for success.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 gboolean
 gcm_x11_screen_assign (GcmX11Screen *screen, GdkScreen *gdk_screen, GError **error)
@@ -227,7 +225,7 @@ gcm_x11_screen_assign (GcmX11Screen *screen, GdkScreen *gdk_screen, GError **err
 	}
 
 	priv->gdk_root = gdk_screen_get_root_window (priv->gdk_screen);
-	priv->xroot = gdk_x11_drawable_get_xid (priv->gdk_root);
+	priv->xroot = gdk_x11_window_get_xid (priv->gdk_root);
 	priv->xdisplay = dpy;
 	priv->xscreen = gdk_x11_screen_get_xscreen (priv->gdk_screen);
 	priv->randr_event_base = event_base;
@@ -256,7 +254,7 @@ gcm_x11_screen_assign (GcmX11Screen *screen, GdkScreen *gdk_screen, GError **err
 			priv->xroot,
 			RRScreenChangeNotifyMask);
 	if (gdk_error_trap_pop ()) {
-		egg_warning ("failed to select input");
+		g_warning ("failed to select input");
 		goto out;
 	}
 
@@ -280,7 +278,7 @@ out:
  *
  * Return value: A #GPtrArray of #GcmX11Output's. Free with g_ptr_array_unref() when done.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 GPtrArray *
 gcm_x11_screen_get_outputs (GcmX11Screen *screen, GError **error)
@@ -308,7 +306,7 @@ gcm_x11_screen_get_outputs (GcmX11Screen *screen, GError **error)
  *
  * Return value: A #GcmX11Output, or %NULL if nothing matched.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 GcmX11Output *
 gcm_x11_screen_get_output_by_name (GcmX11Screen *screen, const gchar *name, GError **error)
@@ -347,6 +345,8 @@ gcm_x11_screen_get_output_by_name (GcmX11Screen *screen, const gchar *name, GErr
  * Gets the ICC profile data from the XServer.
  *
  * Return value: %TRUE for success.
+ *
+ * Since: 2.91.1
  **/
 gboolean
 gcm_x11_screen_get_profile_data (GcmX11Screen *screen, guint8 **data, gsize *length, GError **error)
@@ -408,7 +408,7 @@ out:
  *
  * Return value: %TRUE for success.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 gboolean
 gcm_x11_screen_set_profile (GcmX11Screen *screen, const gchar *filename, GError **error)
@@ -420,7 +420,7 @@ gcm_x11_screen_set_profile (GcmX11Screen *screen, const gchar *filename, GError
 	g_return_val_if_fail (GCM_IS_X11_SCREEN (screen), FALSE);
 	g_return_val_if_fail (filename != NULL, FALSE);
 
-	egg_debug ("setting root window ICC profile atom from %s", filename);
+	g_debug ("setting root window ICC profile atom from %s", filename);
 
 	/* get contents of file */
 	ret = g_file_get_contents (filename, &data, &length, error);
@@ -447,7 +447,7 @@ out:
  *
  * Return value: %TRUE for success.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 gboolean
 gcm_x11_screen_set_profile_data (GcmX11Screen *screen, const guint8 *data, gsize length, GError **error)
@@ -494,7 +494,7 @@ out:
  *
  * Return value: %TRUE for success.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 gboolean
 gcm_x11_screen_set_protocol_version (GcmX11Screen *screen, guint major, guint minor, GError **error)
@@ -541,7 +541,7 @@ out:
  *
  * Return value: %TRUE for success.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 gboolean
 gcm_x11_screen_remove_protocol_version (GcmX11Screen *screen, GError **error)
@@ -553,7 +553,7 @@ gcm_x11_screen_remove_protocol_version (GcmX11Screen *screen, GError **error)
 
 	g_return_val_if_fail (GCM_IS_X11_SCREEN (screen), FALSE);
 
-	egg_debug ("removing root window ICC profile atom");
+	g_debug ("removing root window ICC profile atom");
 
 	/* get the value */
 	gdk_error_trap_push ();
@@ -586,7 +586,7 @@ out:
  *
  * Return value: %TRUE for success.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 gboolean
 gcm_x11_screen_get_protocol_version (GcmX11Screen *screen, guint *major, guint *minor, GError **error)
@@ -645,7 +645,7 @@ out:
  *
  * Return value: %TRUE for success.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 gboolean
 gcm_x11_screen_remove_profile (GcmX11Screen *screen, GError **error)
@@ -657,7 +657,7 @@ gcm_x11_screen_remove_profile (GcmX11Screen *screen, GError **error)
 
 	g_return_val_if_fail (GCM_IS_X11_SCREEN (screen), FALSE);
 
-	egg_debug ("removing root window ICC profile atom");
+	g_debug ("removing root window ICC profile atom");
 
 	/* get the value */
 	gdk_error_trap_push ();
@@ -686,6 +686,8 @@ out:
  * @minor: the returned XRandR version minor, or %NULL
  *
  * Gets the XRandR version from the server.
+ *
+ * Since: 2.91.1
  **/
 void
 gcm_x11_screen_get_randr_version (GcmX11Screen *screen, guint *major, guint *minor)
@@ -708,6 +710,8 @@ gcm_x11_screen_class_init (GcmX11ScreenClass *klass)
 
 	/**
 	 * GcmX11Screen::changed:
+	 *
+	 * Since: 2.91.1
 	 **/
 	signals[SIGNAL_CHANGED] =
 		g_signal_new ("changed",
@@ -749,7 +753,7 @@ gcm_x11_screen_finalize (GObject *object)
  *
  * Return value: a new #GcmX11Screen object.
  *
- * Since: 0.0.1
+ * Since: 2.91.1
  **/
 GcmX11Screen *
 gcm_x11_screen_new (void)
