@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2006-2009 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2006-2010 Richard Hughes <richard@hughsie.com>
  *
  * Color conversion algorithms taken from ppmcie:
  *   Copyright (C) 1999 John Walker <kelvin@fourmilab.ch>
@@ -29,11 +29,9 @@
 #include <stdlib.h>
 #include <math.h>
 
-#include "gcm-xyz.h"
+#include "gcm-color.h"
 #include "gcm-cie-widget.h"
 
-#include "egg-debug.h"
-
 G_DEFINE_TYPE (GcmCieWidget, gcm_cie_widget, GTK_TYPE_DRAWING_AREA);
 #define GCM_CIE_WIDGET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GCM_TYPE_CIE_WIDGET, GcmCieWidgetPrivate))
 #define GCM_CIE_WIDGET_FONT "Sans 8"
@@ -44,7 +42,6 @@ struct GcmCieWidgetPrivate
 	gboolean		 use_whitepoint;
 	guint			 chart_width;
 	guint			 chart_height;
-	cairo_t			*cr;
 	PangoLayout		*layout;
 	GPtrArray		*tongue_buffer;			/* min and max of the tongue shape */
 	guint			 x_offset;
@@ -52,15 +49,11 @@ struct GcmCieWidgetPrivate
 
 	/* CIE x and y coordinates of its three primary illuminants and the
 	 * x and y coordinates of the white point. */
-	gdouble			 red_x;
-	gdouble			 red_y;				/* red primary illuminant */
-	gdouble			 green_x;
-	gdouble			 green_y;			/* green primary illuminant */
-	gdouble			 blue_x;
-	gdouble			 blue_y;			/* blue primary illuminant */
-	gdouble			 white_x;
-	gdouble			 white_y;			/* white point */
-	gdouble			 gamma;				/* gamma of nonlinear correction */
+	GcmColorYxy		*red;			/* red primary illuminant */
+	GcmColorYxy		*green;			/* green primary illuminant */
+	GcmColorYxy		*blue;			/* blue primary illuminant */
+	GcmColorYxy		*white;			/* white point */
+	gdouble			 gamma;			/* gamma of nonlinear correction */
 };
 
 /* The following table gives the spectral chromaticity co-ordinates
@@ -395,7 +388,7 @@ typedef struct {
 	gboolean	 valid;
 } GcmCieWidgetBufferItem;
 
-static gboolean gcm_cie_widget_expose (GtkWidget *cie, GdkEventExpose *event);
+static gboolean gcm_cie_widget_draw (GtkWidget *cie, cairo_t *cr);
 static void	gcm_cie_widget_finalize (GObject *object);
 
 enum
@@ -411,10 +404,10 @@ enum
 };
 
 /**
- * dkp_cie_get_property:
+ * gcm_cie_get_property:
  **/
 static void
-dkp_cie_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
+gcm_cie_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
 	GcmCieWidget *cie = GCM_CIE_WIDGET (object);
 	switch (prop_id) {
@@ -431,13 +424,13 @@ dkp_cie_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec
 }
 
 /**
- * dkp_cie_set_property:
+ * gcm_cie_set_property:
  **/
 static void
-dkp_cie_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
+gcm_cie_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
 	GcmCieWidget *cie = GCM_CIE_WIDGET (object);
-	GcmXyz *xyz;
+	GcmCieWidgetPrivate *priv = cie->priv;
 
 	switch (prop_id) {
 	case PROP_USE_GRID:
@@ -447,24 +440,16 @@ dkp_cie_set_property (GObject *object, guint prop_id, const GValue *value, GPara
 		cie->priv->use_whitepoint = g_value_get_boolean (value);
 		break;
 	case PROP_RED:
-		xyz = g_value_get_object (value);
-		cie->priv->red_x = gcm_xyz_get_x (xyz);
-		cie->priv->red_y = gcm_xyz_get_y (xyz);
+		gcm_color_copy_Yxy (g_value_get_boxed (value), priv->red);
 		break;
 	case PROP_GREEN:
-		xyz = g_value_get_object (value);
-		cie->priv->green_x = gcm_xyz_get_x (xyz);
-		cie->priv->green_y = gcm_xyz_get_y (xyz);
+		gcm_color_copy_Yxy (g_value_get_boxed (value), priv->green);
 		break;
 	case PROP_BLUE:
-		xyz = g_value_get_object (value);
-		cie->priv->blue_x = gcm_xyz_get_x (xyz);
-		cie->priv->blue_y = gcm_xyz_get_y (xyz);
+		gcm_color_copy_Yxy (g_value_get_boxed (value), priv->blue);
 		break;
 	case PROP_WHITE:
-		xyz = g_value_get_object (value);
-		cie->priv->white_x = gcm_xyz_get_x (xyz);
-		cie->priv->white_y = gcm_xyz_get_y (xyz);
+		gcm_color_copy_Yxy (g_value_get_boxed (value), priv->white);
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -485,9 +470,9 @@ gcm_cie_widget_class_init (GcmCieWidgetClass *class)
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class);
 	GObjectClass *object_class = G_OBJECT_CLASS (class);
 
-	widget_class->expose_event = gcm_cie_widget_expose;
-	object_class->get_property = dkp_cie_get_property;
-	object_class->set_property = dkp_cie_set_property;
+	widget_class->draw = gcm_cie_widget_draw;
+	object_class->get_property = gcm_cie_get_property;
+	object_class->set_property = gcm_cie_set_property;
 	object_class->finalize = gcm_cie_widget_finalize;
 
 	g_type_class_add_private (class, sizeof (GcmCieWidgetPrivate));
@@ -505,24 +490,65 @@ gcm_cie_widget_class_init (GcmCieWidgetClass *class)
 							       G_PARAM_READWRITE));
 	g_object_class_install_property (object_class,
 					 PROP_RED,
-					 g_param_spec_object ("red", NULL, NULL,
-							      GCM_TYPE_XYZ,
-							      G_PARAM_WRITABLE));
+					 g_param_spec_boxed ("red", NULL, NULL,
+							     GCM_TYPE_COLOR_YXY,
+							     G_PARAM_WRITABLE));
 	g_object_class_install_property (object_class,
 					 PROP_GREEN,
-					 g_param_spec_object ("green", NULL, NULL,
-							      GCM_TYPE_XYZ,
-							      G_PARAM_WRITABLE));
+					 g_param_spec_boxed ("green", NULL, NULL,
+							     GCM_TYPE_COLOR_YXY,
+							     G_PARAM_WRITABLE));
 	g_object_class_install_property (object_class,
 					 PROP_BLUE,
-					 g_param_spec_object ("blue", NULL, NULL,
-							      GCM_TYPE_XYZ,
-							      G_PARAM_WRITABLE));
+					 g_param_spec_boxed ("blue", NULL, NULL,
+							     GCM_TYPE_COLOR_YXY,
+							     G_PARAM_WRITABLE));
 	g_object_class_install_property (object_class,
 					 PROP_WHITE,
-					 g_param_spec_object ("white", NULL, NULL,
-							      GCM_TYPE_XYZ,
-							      G_PARAM_WRITABLE));
+					 g_param_spec_boxed ("white", NULL, NULL,
+							     GCM_TYPE_COLOR_YXY,
+							     G_PARAM_WRITABLE));
+}
+
+/**
+ * gcm_cie_widget_set_from_profile:
+ **/
+void
+gcm_cie_widget_set_from_profile (GtkWidget *widget, GcmProfile *profile)
+{
+	GcmCieWidget *cie = GCM_CIE_WIDGET (widget);
+	GcmColorXYZ *white;
+	GcmColorXYZ *red;
+	GcmColorXYZ *green;
+	GcmColorXYZ *blue;
+
+	/* get the new details from the profile */
+	g_object_get (profile,
+		      "white", &white,
+		      "red", &red,
+		      "green", &green,
+		      "blue", &blue,
+		      NULL);
+
+	/* copy into this widget */
+	gcm_color_convert_XYZ_to_Yxy (white, cie->priv->white);
+	gcm_color_convert_XYZ_to_Yxy (red, cie->priv->red);
+	gcm_color_convert_XYZ_to_Yxy (green, cie->priv->green);
+	gcm_color_convert_XYZ_to_Yxy (blue, cie->priv->blue);
+
+	/* hide if we have no data */
+	if (cie->priv->white->x > 0.001) {
+		gtk_widget_hide (widget);
+		gtk_widget_show (widget);
+	} else {
+		gtk_widget_hide (widget);
+	}
+
+	/* free */
+	gcm_color_free_XYZ (white);
+	gcm_color_free_XYZ (red);
+	gcm_color_free_XYZ (green);
+	gcm_color_free_XYZ (blue);
 }
 
 /**
@@ -541,14 +567,18 @@ gcm_cie_widget_init (GcmCieWidget *cie)
 	cie->priv->tongue_buffer = g_ptr_array_new_with_free_func (g_free);
 
 	/* default is CIE REC 709 */
-	cie->priv->red_x = 0.64;
-	cie->priv->red_y = 0.33;
-	cie->priv->green_x = 0.30;
-	cie->priv->green_y = 0.60;
-	cie->priv->blue_x = 0.15;
-	cie->priv->blue_y = 0.06;
-	cie->priv->white_x = 0.3127;
-	cie->priv->white_y = 0.3291;
+	cie->priv->red = gcm_color_new_Yxy ();
+	cie->priv->green = gcm_color_new_Yxy ();
+	cie->priv->blue = gcm_color_new_Yxy ();
+	cie->priv->white = gcm_color_new_Yxy ();
+	cie->priv->red->x = 0.64;
+	cie->priv->red->y = 0.33;
+	cie->priv->green->x = 0.30;
+	cie->priv->green->y = 0.60;
+	cie->priv->blue->x = 0.15;
+	cie->priv->blue->y = 0.06;
+	cie->priv->white->x = 0.3127;
+	cie->priv->white->y = 0.3291;
 	cie->priv->gamma = 0.0;
 
 	/* do pango stuff */
@@ -573,6 +603,10 @@ gcm_cie_widget_finalize (GObject *object)
 
 	context = pango_layout_get_context (cie->priv->layout);
 	g_object_unref (cie->priv->layout);
+	gcm_color_free_Yxy (cie->priv->white);
+	gcm_color_free_Yxy (cie->priv->red);
+	gcm_color_free_Yxy (cie->priv->green);
+	gcm_color_free_Yxy (cie->priv->blue);
 	g_object_unref (context);
 	g_ptr_array_unref (cie->priv->tongue_buffer);
 	G_OBJECT_CLASS (gcm_cie_widget_parent_class)->finalize (object);
@@ -836,13 +870,13 @@ gcm_cie_widget_xyz_to_rgb (GcmCieWidget *cie,
 	gdouble rw, gw, bw;
 	GcmCieWidgetPrivate *priv = cie->priv;
 
-	xr = priv->red_x; yr = priv->red_y; zr = 1 - (xr + yr);
-	xg = priv->green_x; yg = priv->green_y; zg = 1 - (xg + yg);
-	xb = priv->blue_x; yb = priv->blue_y; zb = 1 - (xb + yb);
+	xr = priv->red->x; yr = priv->red->y; zr = 1 - (xr + yr);
+	xg = priv->green->x; yg = priv->green->y; zg = 1 - (xg + yg);
+	xb = priv->blue->x; yb = priv->blue->y; zb = 1 - (xb + yb);
 
-	xw = priv->white_x; yw = priv->white_y; zw = 1 - (xw + yw);
+	xw = priv->white->x; yw = priv->white->y; zw = 1 - (xw + yw);
 
-	/* xyz -> rgb matrix, before scaling to white. */
+	/* xyz -> rgb matrix, before scaling to white-> */
 	rx = yg*zb - yb*zg; ry = xb*zg - xg*zb; rz = xg*yb - xb*yg;
 	gx = yb*zr - yr*zb; gy = xr*zb - xb*zr; gz = xb*yr - xr*yb;
 	bx = yr*zg - yg*zr; by = xg*zr - xr*zg; bz = xr*yg - xg*yr;
@@ -852,7 +886,7 @@ gcm_cie_widget_xyz_to_rgb (GcmCieWidget *cie,
 	gw = (gx*xw + gy*yw + gz*zw) / yw;
 	bw = (bx*xw + by*yw + bz*zw) / yw;
 
-	/* xyz -> rgb matrix, correctly scaled to white. */
+	/* xyz -> rgb matrix, correctly scaled to white-> */
 	rx = rx / rw; ry = ry / rw; rz = rz / rw;
 	gx = gx / gw; gy = gy / gw; gz = gz / gw;
 	bx = bx / bw; by = by / bw; bz = bz / bw;
@@ -950,17 +984,17 @@ gcm_cie_widget_draw_gamut_outline (GcmCieWidget *cie, cairo_t *cr)
 	cairo_set_line_width (cr, 0.9f);
 	cairo_set_source_rgb (cr, 0.0f, 0.0f, 0.0f);
 
-	gcm_cie_widget_map_to_display (cie, priv->red_x, priv->red_y, &wx, &wy);
+	gcm_cie_widget_map_to_display (cie, priv->red->x, priv->red->y, &wx, &wy);
 	if (wx < 0 || wy < 0)
 		goto out;
 	cairo_move_to (cr, wx, wy);
 
-	gcm_cie_widget_map_to_display (cie, priv->green_x, priv->green_y, &wx, &wy);
+	gcm_cie_widget_map_to_display (cie, priv->green->x, priv->green->y, &wx, &wy);
 	if (wx < 0 || wy < 0)
 		goto out;
 	cairo_line_to (cr, wx, wy);
 
-	gcm_cie_widget_map_to_display (cie, priv->blue_x, priv->blue_y, &wx, &wy);
+	gcm_cie_widget_map_to_display (cie, priv->blue->x, priv->blue->y, &wx, &wy);
 	if (wx < 0 || wy < 0)
 		goto out;
 	cairo_line_to (cr, wx, wy);
@@ -992,12 +1026,12 @@ gcm_cie_widget_draw_white_point_cross (GcmCieWidget *cie, cairo_t *cr)
 	cairo_set_line_width (cr, 1.0f);
 
 	/* choose color of cross */
-	if (priv->red_x < 0.001 && priv->green_x < 0.001 && priv->blue_x < 0.001)
+	if (priv->red->x < 0.001 && priv->green->x < 0.001 && priv->blue->x < 0.001)
 		cairo_set_source_rgb (cr, 1.0f, 1.0f, 1.0f);
 	else
 		cairo_set_source_rgb (cr, 0.0f, 0.0f, 0.0f);
 
-	gcm_cie_widget_map_to_display (cie, priv->white_x, priv->white_y, &wx, &wy);
+	gcm_cie_widget_map_to_display (cie, priv->white->x, priv->white->y, &wx, &wy);
 
 	/* don't antialias the cross */
 	wx = (gint) wx + 0.5f;
@@ -1153,26 +1187,14 @@ gcm_cie_widget_draw_cie (GtkWidget *cie_widget, cairo_t *cr)
 }
 
 /**
- * gcm_cie_widget_expose:
+ * gcm_cie_widget_draw:
  *
  * Just repaint the entire cie widget on expose.
  **/
 static gboolean
-gcm_cie_widget_expose (GtkWidget *cie, GdkEventExpose *event)
+gcm_cie_widget_draw (GtkWidget *cie, cairo_t *cr)
 {
-	cairo_t *cr;
-
-	/* get a cairo_t */
-	cr = gdk_cairo_create (gtk_widget_get_window (cie));
-	cairo_rectangle (cr,
-			 event->area.x, event->area.y,
-			 event->area.width, event->area.height);
-	cairo_clip (cr);
-	((GcmCieWidget *)cie)->priv->cr = cr;
-
 	gcm_cie_widget_draw_cie (cie, cr);
-
-	cairo_destroy (cr);
 	return FALSE;
 }
 
@@ -1186,98 +1208,3 @@ gcm_cie_widget_new (void)
 	return g_object_new (GCM_TYPE_CIE_WIDGET, NULL);
 }
 
-/***************************************************************************
- ***                          MAKE CHECK TESTS                           ***
- ***************************************************************************/
-#ifdef EGG_TEST
-#include "egg-test.h"
-
-#include "gcm-profile.h"
-#include "gcm-xyz.h"
-
-void
-gcm_cie_widget_test (EggTest *test)
-{
-	GtkWidget *widget;
-	GtkWidget *image;
-	GtkWidget *dialog;
-	GtkWidget *vbox;
-	gboolean ret;
-	GError *error = NULL;
-	GcmProfile *profile;
-	GcmXyz *white;
-	GcmXyz *red;
-	GcmXyz *green;
-	GcmXyz *blue;
-	gint response;
-	gchar *filename_profile;
-	gchar *filename_image;
-	GFile *file = NULL;
-
-	if (!egg_test_start (test, "GcmCieWidget"))
-		return;
-
-	/************************************************************/
-	egg_test_title (test, "get a CIE widget object");
-	widget = gcm_cie_widget_new ();
-	egg_test_assert (test, widget != NULL);
-
-	/************************************************************/
-	egg_test_title (test, "get filename of image file");
-	filename_image = egg_test_get_data_file ("cie-widget.png");
-	egg_test_assert (test, (filename_image != NULL));
-
-	/************************************************************/
-	egg_test_title (test, "get filename of data file");
-	filename_profile = egg_test_get_data_file ("bluish.icc");
-	egg_test_assert (test, (filename_profile != NULL));
-
-	profile = gcm_profile_default_new ();
-	file = g_file_new_for_path (filename_profile);
-	gcm_profile_parse (profile, file, NULL);
-	g_object_get (profile,
-		      "white-point", &white,
-		      "luminance-red", &red,
-		      "luminance-green", &green,
-		      "luminance-blue", &blue,
-		      NULL);
-	g_object_unref (file);
-
-	g_object_set (widget,
-		      "red", red,
-		      "green", green,
-		      "blue", blue,
-		      "white", white,
-		      NULL);
-
-	/* show in a dialog as an example */
-	dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, "Does CIE widget match\nthe picture below?");
-	image = gtk_image_new_from_file (filename_image);
-	vbox = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
-	gtk_box_pack_end (GTK_BOX(vbox), widget, TRUE, TRUE, 12);
-	gtk_box_pack_end (GTK_BOX(vbox), image, TRUE, TRUE, 12);
-	gtk_widget_set_size_request (widget, 300, 300);
-	gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
-	gtk_widget_show (widget);
-	gtk_widget_show (image);
-
-	response = gtk_dialog_run (GTK_DIALOG (dialog));
-
-	/************************************************************/
-	egg_test_title (test, "plotted as expected?");
-	egg_test_assert (test, (response == GTK_RESPONSE_YES));
-
-	gtk_widget_destroy (dialog);
-
-	g_object_unref (profile);
-	g_object_unref (white);
-	g_object_unref (red);
-	g_object_unref (green);
-	g_object_unref (blue);
-	g_free (filename_profile);
-	g_free (filename_image);
-
-	egg_test_end (test);
-}
-#endif
-
