@@ -34,8 +34,6 @@
 #include "gcm-profile.h"
 #include "gcm-utils.h"
 
-#include "egg-debug.h"
-
 static void     gcm_device_finalize	(GObject     *object);
 
 #define GCM_DEVICE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GCM_TYPE_DEVICE, GcmDevicePrivate))
@@ -49,6 +47,7 @@ struct _GcmDevicePrivate
 {
 	gboolean		 connected;
 	gboolean		 virtual;
+	gboolean		 use_edid_profile;
 	gboolean		 saved;
 	gfloat			 gamma;
 	gfloat			 brightness;
@@ -60,7 +59,6 @@ struct _GcmDevicePrivate
 	gchar			*model;
 	GPtrArray		*profiles;
 	gchar			*title;
-	GSettings		*settings;
 	GcmColorspace		 colorspace;
 	guint			 changed_id;
 	glong			 modified_time;
@@ -72,6 +70,7 @@ enum {
 	PROP_ID,
 	PROP_CONNECTED,
 	PROP_VIRTUAL,
+	PROP_USE_EDID_PROFILE,
 	PROP_SAVED,
 	PROP_SERIAL,
 	PROP_MODEL,
@@ -103,7 +102,7 @@ static gboolean
 gcm_device_changed_cb (GcmDevice *device)
 {
 	/* emit a signal */
-	egg_debug ("emit changed: %s", gcm_device_get_id (device));
+	g_debug ("emit changed: %s", gcm_device_get_id (device));
 	g_signal_emit (device, signals[SIGNAL_CHANGED], 0);
 	device->priv->changed_id = 0;
 	return FALSE;
@@ -192,7 +191,7 @@ gcm_device_load_from_default_profile (GcmDevice *device, GError **error)
 	profile = g_ptr_array_index (priv->profiles, 0);
 	ret = g_file_test (gcm_profile_get_filename (profile), G_FILE_TEST_EXISTS);
 	if (!ret) {
-		egg_warning ("the file was deleted and can't be loaded: %s", gcm_profile_get_filename (profile));
+		g_warning ("the file was deleted and can't be loaded: %s", gcm_profile_get_filename (profile));
 		/* this is not fatal */
 		ret = TRUE;
 		goto out;
@@ -268,6 +267,27 @@ gcm_device_set_virtual (GcmDevice *device, gboolean virtual)
 	gcm_device_changed (device);
 }
 
+/**
+ * gcm_device_get_use_edid_profile:
+ **/
+gboolean
+gcm_device_get_use_edid_profile (GcmDevice *device)
+{
+	g_return_val_if_fail (GCM_IS_DEVICE (device), FALSE);
+	return device->priv->use_edid_profile;
+}
+
+/**
+ * gcm_device_set_use_edid_profile:
+ **/
+void
+gcm_device_set_use_edid_profile (GcmDevice *device, gboolean use_edid_profile)
+{
+	g_return_if_fail (GCM_IS_DEVICE (device));
+	device->priv->use_edid_profile = use_edid_profile;
+	gcm_device_changed (device);
+}
+
 /**
  * gcm_device_get_saved:
  **/
@@ -509,6 +529,137 @@ gcm_device_set_profiles (GcmDevice *device, GPtrArray *profiles)
 	gcm_device_changed (device);
 }
 
+/**
+ * gcm_device_profile_add:
+ **/
+gboolean
+gcm_device_profile_add (GcmDevice *device, GcmProfile *profile, GError **error)
+{
+	guint i;
+	gboolean ret = FALSE;
+	const gchar *md5;
+	GcmProfile *profile_tmp;
+
+	g_return_val_if_fail (GCM_IS_DEVICE (device), FALSE);
+	g_return_val_if_fail (profile != NULL, FALSE);
+
+	/* check if already exists */
+	md5 = gcm_profile_get_checksum (profile);
+	for (i=0; i<device->priv->profiles->len; i++) {
+		profile_tmp = g_ptr_array_index (device->priv->profiles, i);
+		if (g_strcmp0 (md5, gcm_profile_get_checksum (profile_tmp)) == 0) {
+			g_set_error (error, GCM_DEVICE_ERROR, GCM_DEVICE_ERROR_INTERNAL,
+				     "already added %s", gcm_profile_get_filename (profile));
+			goto out;
+		}
+	}
+
+	/* add */
+	g_ptr_array_add (device->priv->profiles, g_object_ref (profile));
+	gcm_device_changed (device);
+	ret = TRUE;
+out:
+	return ret;
+}
+
+/**
+ * gcm_device_profile_remove:
+ **/
+gboolean
+gcm_device_profile_remove (GcmDevice *device, GcmProfile *profile, GError **error)
+{
+	guint i;
+	gboolean ret = TRUE;
+	const gchar *md5;
+	GcmProfile *profile_tmp;
+
+	g_return_val_if_fail (GCM_IS_DEVICE (device), FALSE);
+	g_return_val_if_fail (profile != NULL, FALSE);
+
+	/* array empty */
+	if (device->priv->profiles->len == 0) {
+		g_set_error_literal (error, GCM_DEVICE_ERROR, GCM_DEVICE_ERROR_INTERNAL,
+				     "the profile array is empty");
+		ret = FALSE;
+		goto out;
+	}
+
+	/* check if exists */
+	md5 = gcm_profile_get_checksum (profile);
+	for (i=0; i<device->priv->profiles->len; i++) {
+		profile_tmp = g_ptr_array_index (device->priv->profiles, i);
+		if (g_strcmp0 (md5, gcm_profile_get_checksum (profile_tmp)) == 0) {
+			g_ptr_array_remove_index (device->priv->profiles, i);
+			gcm_device_changed (device);
+			goto out;
+		}
+	}
+
+	/* not present */
+	g_set_error (error, GCM_DEVICE_ERROR, GCM_DEVICE_ERROR_INTERNAL,
+		     "asked to remove %s that does not exist",
+		     gcm_profile_get_filename (profile));
+	ret = FALSE;
+out:
+	return ret;
+}
+
+/**
+ * gcm_device_profile_set_default:
+ **/
+gboolean
+gcm_device_profile_set_default (GcmDevice *device, GcmProfile *profile, GError **error)
+{
+	guint i;
+	gboolean ret = TRUE;
+	const gchar *md5;
+	GcmProfile *profile_tmp;
+	gpointer tmp;
+
+	g_return_val_if_fail (GCM_IS_DEVICE (device), FALSE);
+	g_return_val_if_fail (profile != NULL, FALSE);
+
+	/* array empty */
+	if (device->priv->profiles->len == 0) {
+		g_set_error_literal (error, GCM_DEVICE_ERROR, GCM_DEVICE_ERROR_INTERNAL,
+				     "the profile array is empty");
+		ret = FALSE;
+		goto out;
+	}
+
+	/* only one item */
+	if (device->priv->profiles->len == 1)
+		goto out;
+
+	/* check if exists */
+	md5 = gcm_profile_get_checksum (profile);
+	for (i=0; i<device->priv->profiles->len; i++) {
+		profile_tmp = g_ptr_array_index (device->priv->profiles, i);
+		if (g_strcmp0 (md5, gcm_profile_get_checksum (profile_tmp)) == 0) {
+			if (i == 0) {
+				g_set_error_literal (error, GCM_DEVICE_ERROR, GCM_DEVICE_ERROR_INTERNAL,
+						     "profile already set default");
+				ret = FALSE;
+				goto out;
+			}
+			/* swap the two pointer locations */
+			tmp = device->priv->profiles->pdata[0];
+			device->priv->profiles->pdata[0] = device->priv->profiles->pdata[i];
+			device->priv->profiles->pdata[i] = tmp;
+			gcm_device_changed (device);
+			goto out;
+		}
+	}
+
+	/* not present */
+	g_set_error (error, GCM_DEVICE_ERROR, GCM_DEVICE_ERROR_INTERNAL,
+		     "asked to set default %s that does not exist in list",
+		     gcm_profile_get_filename (profile));
+	ret = FALSE;
+out:
+	return ret;
+}
+
 /**
  * gcm_device_get_default_profile_filename:
  **/
@@ -559,7 +710,7 @@ gcm_device_set_default_profile_filename (GcmDevice *device, const gchar *profile
 	file = g_file_new_for_path (profile_filename);
 	ret = gcm_profile_parse (profile, file, &error);
 	if (!ret) {
-		egg_warning ("failed to parse: %s", error->message);
+		g_warning ("failed to parse: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
@@ -620,7 +771,6 @@ gcm_device_load (GcmDevice *device, GError **error)
 	ret = g_key_file_load_from_file (file, filename, G_KEY_FILE_NONE, &error_local);
 	if (!ret) {
 		/* not fatal */
-		egg_warning ("failed to load from file: %s", error_local->message);
 		g_error_free (error_local);
 		ret = TRUE;
 		goto out;
@@ -630,7 +780,7 @@ gcm_device_load (GcmDevice *device, GError **error)
 	ret = g_key_file_has_group (file, priv->id);
 	if (!ret) {
 		/* not fatal */
-		egg_debug ("failed to find saved parameters for %s", priv->id);
+		g_debug ("failed to find saved parameters for %s", priv->id);
 		ret = TRUE;
 		goto out;
 	}
@@ -651,7 +801,7 @@ gcm_device_load (GcmDevice *device, GError **error)
 			if (ret) {
 				g_ptr_array_add (priv->profiles, g_object_ref (profile));
 			} else {
-				egg_warning ("failed to parse %s: %s", profile_filenames[i], error_local->message);
+				g_warning ("failed to parse %s: %s", profile_filenames[i], error_local->message);
 				g_clear_error (&error_local);
 			}
 			g_object_unref (profile);
@@ -667,9 +817,7 @@ gcm_device_load (GcmDevice *device, GError **error)
 		priv->manufacturer = g_key_file_get_string (file, priv->id, "manufacturer", NULL);
 	priv->gamma = g_key_file_get_double (file, priv->id, "gamma", &error_local);
 	if (error_local != NULL) {
-		priv->gamma = g_settings_get_double (priv->settings, GCM_SETTINGS_DEFAULT_GAMMA);
-		if (priv->gamma < 0.1f)
-			priv->gamma = 1.0f;
+		priv->gamma = 1;
 		g_clear_error (&error_local);
 	}
 	priv->brightness = g_key_file_get_double (file, priv->id, "brightness", &error_local);
@@ -688,7 +836,7 @@ gcm_device_load (GcmDevice *device, GError **error)
 	if (iso_date != NULL) {
 		ret = g_time_val_from_iso8601 (iso_date, &timeval);
 		if (!ret) {
-			egg_warning ("failed to parse: %s", iso_date);
+			g_warning ("failed to parse: %s", iso_date);
 			g_get_current_time (&timeval);
 		}
 	} else {
@@ -697,12 +845,22 @@ gcm_device_load (GcmDevice *device, GError **error)
 	}
 	priv->modified_time = timeval.tv_sec;
 
+	/* should we load the virtual profile */
+	priv->use_edid_profile = g_key_file_get_boolean (file, priv->id, "use-edid-profile", &error_local);
+	if (error_local != NULL) {
+		/* if the key does not exist, and this is a display,
+		 * then enable it by default */
+		if (gcm_device_get_kind (device) == GCM_DEVICE_KIND_DISPLAY)
+			priv->use_edid_profile = TRUE;
+		g_clear_error (&error_local);
+	}
+
 	/* load this */
 	ret = gcm_device_load_from_default_profile (device, &error_local);
 	if (!ret) {
 
 		/* just print a warning, this is not fatal */
-		egg_warning ("failed to load profile %s", error_local->message);
+		g_warning ("failed to load profile %s", error_local->message);
 		g_error_free (error_local);
 
 		/* recover as the file might have been corrupted */
@@ -857,6 +1015,10 @@ gcm_device_save (GcmDevice *device, GError **error)
 	if (priv->virtual)
 		g_key_file_set_boolean (keyfile, priv->id, "virtual", TRUE);
 
+	/* add use_edid_profile */
+	if (priv->kind == GCM_DEVICE_KIND_DISPLAY)
+		g_key_file_set_boolean (keyfile, priv->id, "use-edid-profile", priv->use_edid_profile);
+
 	/* get extra, device specific config data */
 	if (klass->get_config_data != NULL) {
 		config_data = klass->get_config_data (device);
@@ -915,7 +1077,7 @@ gcm_device_apply (GcmDevice *device, GError **error)
 
 	/* no support */
 	if (klass->apply == NULL) {
-		egg_debug ("no klass support for %s", device->priv->id);
+		g_debug ("no klass support for %s", device->priv->id);
 		goto out;
 	}
 
@@ -925,6 +1087,28 @@ out:
 	return ret;
 }
 
+/**
+ * gcm_device_generate_profile:
+ **/
+GcmProfile *
+gcm_device_generate_profile (GcmDevice *device, GError **error)
+{
+	GcmProfile *profile = NULL;
+	GcmDeviceClass *klass = GCM_DEVICE_GET_CLASS (device);
+
+	/* no support */
+	if (klass->generate_profile == NULL) {
+		g_set_error (error, GCM_DEVICE_ERROR, GCM_DEVICE_ERROR_NO_SUPPPORT,
+			     "no klass support for %s", device->priv->id);
+		goto out;
+	}
+
+	/* run the callback */
+	profile = klass->generate_profile (device, error);
+out:
+	return profile;
+}
+
 /**
  * gcm_device_get_property:
  **/
@@ -947,6 +1131,9 @@ gcm_device_get_property (GObject *object, guint prop_id, GValue *value, GParamSp
 	case PROP_VIRTUAL:
 		g_value_set_boolean (value, priv->virtual);
 		break;
+	case PROP_USE_EDID_PROFILE:
+		g_value_set_boolean (value, priv->use_edid_profile);
+		break;
 	case PROP_SAVED:
 		g_value_set_boolean (value, priv->saved);
 		break;
@@ -1004,6 +1191,9 @@ gcm_device_set_property (GObject *object, guint prop_id, const GValue *value, GP
 	case PROP_VIRTUAL:
 		gcm_device_set_virtual (device, g_value_get_boolean (value));
 		break;
+	case PROP_USE_EDID_PROFILE:
+		gcm_device_set_use_edid_profile (device, g_value_get_boolean (value));
+		break;
 	case PROP_SAVED:
 		gcm_device_set_saved (device, g_value_get_boolean (value));
 		break;
@@ -1084,6 +1274,14 @@ gcm_device_class_init (GcmDeviceClass *klass)
 				      G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_VIRTUAL, pspec);
 
+	/**
+	 * GcmDevice:use-edid-profile:
+	 */
+	pspec = g_param_spec_boolean ("use-edid-profile", NULL, NULL,
+				      FALSE,
+				      G_PARAM_READWRITE);
+	g_object_class_install_property (object_class, PROP_USE_EDID_PROFILE, pspec);
+
 	/**
 	 * GcmDevice:saved:
 	 */
@@ -1188,15 +1386,13 @@ gcm_device_init (GcmDevice *device)
 	device->priv->saved = FALSE;
 	device->priv->connected = FALSE;
 	device->priv->virtual = FALSE;
+	device->priv->use_edid_profile = TRUE;
 	device->priv->serial = NULL;
 	device->priv->manufacturer = NULL;
 	device->priv->model = NULL;
 	device->priv->profiles = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
 	device->priv->modified_time = 0;
-	device->priv->settings = g_settings_new (GCM_SETTINGS_SCHEMA);
-	device->priv->gamma = g_settings_get_double (device->priv->settings, GCM_SETTINGS_DEFAULT_GAMMA);
-	if (device->priv->gamma < 0.01)
-		device->priv->gamma = 1.0f;
+	device->priv->gamma = 1.0;
 	device->priv->brightness = 0.0f;
 	device->priv->contrast = 100.f;
 	device->priv->colorspace = GCM_COLORSPACE_UNKNOWN;
@@ -1221,7 +1417,6 @@ gcm_device_finalize (GObject *object)
 	g_free (priv->manufacturer);
 	g_free (priv->model);
 	g_ptr_array_unref (priv->profiles);
-	g_object_unref (priv->settings);
 
 	G_OBJECT_CLASS (gcm_device_parent_class)->finalize (object);
 }
